@@ -8,12 +8,6 @@ def mixin_hub_pull_options_parser(parser):
     """
 
     gp = add_arg_group(parser, title='Pull')
-    gp.add_argument(
-        '--install-requirements',
-        action='store_true',
-        default=False,
-        help='If set, install `requirements.txt` in the Hub Executor bundle to local',
-    ),
     gp.add_argument(
         '--force-update',
         '--force',
@@ -21,6 +15,13 @@ def mixin_hub_pull_options_parser(parser):
         default=False,
         help='If set, always pull the latest Hub Executor bundle even it exists on local',
     )
+    gp.add_argument(
+        '--prefer-platform',
+        type=str,
+        help='The preferred target Docker platform. (e.g. "linux/amd64", "linux/arm64")',
+    )
+
+    return gp
 
 
 def mixin_hub_pull_parser(parser):
@@ -39,4 +40,10 @@ def mixin_hub_pull_parser(parser):
         type=hub_uri,
         help='The URI of the executor to pull (e.g., jinaai[+docker]://<username>/NAME)',
     )
-    mixin_hub_pull_options_parser(parser)
+    pull_group = mixin_hub_pull_options_parser(parser)
+    pull_group.add_argument(
+        '--install-requirements',
+        action='store_true',
+        default=False,
+        help='If set, install `requirements.txt` in the Hub Executor bundle to local',
+    ),
